@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE. 
  *
- *  $Id: catalog.cpp,v 1.84 2005/06/19 16:43:20 vaclavslavik Exp $
+ *  $Id: catalog.cpp,v 1.85 2005/08/28 20:10:15 vaclavslavik Exp $
  *
  *  Translations catalog
  *
@@ -67,7 +67,9 @@ static wxString ReadTextLine(wxTextFile* f, wxMBConv *conv)
     while (s.IsEmpty())
     {
         if (f->Eof()) return wxEmptyString;
-        s = f->GetNextLine();
+
+        // read next line and strip insignificant whitespace from it:
+        s = f->GetNextLine().Strip(wxString::both);
     }
 #if !wxUSE_UNICODE
     if (conv)
