@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE. 
  *
- *  $Id: edframe.cpp,v 1.122 2005/06/26 21:18:38 vaclavslavik Exp $
+ *  $Id: edframe.cpp,v 1.129 2005/09/30 22:30:28 vaclavslavik Exp $
  *
  *  Editor frame
  *
@@ -343,7 +343,7 @@ poEditFrame::poEditFrame() :
                                  wxConfig::Get()->Read(_T("frame_w"), 600),
                                  wxConfig::Get()->Read(_T("frame_h"), 400)),
                              wxDEFAULT_FRAME_STYLE | wxNO_FULL_REPAINT_ON_RESIZE),
-    m_itemBeingValidated(-1),
+    m_itemBeingValidated(-1), m_gettextProcess(NULL),
     m_catalog(NULL),
 #ifdef USE_TRANSMEM
     m_transMem(NULL),
@@ -369,6 +369,11 @@ poEditFrame::poEditFrame() :
     //     recognize that there are many of them
     if (ms_instances.GetCount() == 0)
         Move(cfg->Read(_T("frame_x"), -1), cfg->Read(_T("frame_y"), -1));
+#if !defined(__WXGTK12__) || defined(__WXGTK20__)
+    // GTK+ 1.2 doesn't support this
+    if (cfg->Read(_T("frame_maximized"), long(0)))
+        Maximize();
+#endif
 
     m_displayQuotes = (bool)cfg->Read(_T("display_quotes"), (long)false);
     m_displayLines = (bool)cfg->Read(_T("display_lines"), (long)false);
@@ -462,6 +467,9 @@ poEditFrame::poEditFrame() :
                                 wxDefaultPosition, wxDefaultSize,
                                 wxTE_MULTILINE);
 
+    // in case of plurals form, this is the control for n=1:
+    m_textTransSingularForm = NULL;
+
     m_pluralNotebook = new wxNotebook(m_bottomLeftPanel, -1);
 
     SetCustomFonts();
@@ -558,6 +566,9 @@ poEditFrame::poEditFrame() :
 
 poEditFrame::~poEditFrame()
 {
+    if (m_gettextProcess)
+        m_gettextProcess->Detach();
+
     ms_instances.DeleteObject(this);
 
     GetStatusBar()->PopEventHandler(true/*delete*/);
@@ -567,13 +578,19 @@ poEditFrame::~poEditFrame()
     wxSize sz = GetSize();
     wxPoint pos = GetPosition();
     wxConfigBase *cfg = wxConfig::Get();
-    if (!IsIconized())
+    if (!IsIconized() && !IsFullScreen())
     {
-        cfg->Write(_T("frame_w"), (long)sz.x);
-        cfg->Write(_T("frame_h"), (long)sz.y);
-        cfg->Write(_T("frame_x"), (long)pos.x);
-        cfg->Write(_T("frame_y"), (long)pos.y);
+        if (!IsMaximized())
+        {
+            cfg->Write(_T("frame_w"), (long)sz.x);
+            cfg->Write(_T("frame_h"), (long)sz.y);
+            cfg->Write(_T("frame_x"), (long)pos.x);
+            cfg->Write(_T("frame_y"), (long)pos.y);
+        }
+
+        cfg->Write(_T("frame_maximized"), (long)IsMaximized());
     }
+
     if (m_displayCommentWin)
         cfg->Write(_T("bottom_splitter"),
                    (long)m_bottomSplitter->GetSashPosition());
@@ -742,9 +759,9 @@ void poEditFrame::OnCloseWindow(wxCloseEvent&)
         {
             return;
         }
-
-        CancelItemsValidation();
     }
+
+    CancelItemsValidation();
     Destroy();
 }
 
@@ -883,27 +900,42 @@ static wxString SuggestFileName(const Catalog *catalog)
         return name;
 }
 
-void poEditFrame::OnSaveAs(wxCommandEvent&)
+wxString poEditFrame::GetSaveAsFilename(Catalog *cat, const wxString& current)
 {
-    UpdateFromTextCtrl();
-
-    wxString name(wxFileNameFromPath(m_fileName));
-    wxString path(wxPathOnly(m_fileName));
+    wxString name(wxFileNameFromPath(current));
+    wxString path(wxPathOnly(current));
 
     if (name.empty())
     {
         path = wxConfig::Get()->Read(_T("last_file_path"), wxEmptyString);
-        name = SuggestFileName(m_catalog) + _T(".po");
+        name = SuggestFileName(cat) + _T(".po");
     }
 
     name = wxFileSelector(_("Save as..."), path, name, wxEmptyString,
                           _("GNU GetText catalogs (*.po)|*.po|All files (*.*)|*.*"),
                           wxSAVE | wxOVERWRITE_PROMPT, this);
-    if (!name.IsEmpty())
+    if (!name.empty())
     {
         wxConfig::Get()->Write(_T("last_file_path"), wxPathOnly(name));
-        WriteCatalog(name);
     }
+
+    return name;
+}
+
+void poEditFrame::DoSaveAs(const wxString& filename)
+{
+    if (filename.empty())
+        return;
+
+    UpdateFromTextCtrl();
+
+    m_fileName = filename;
+    WriteCatalog(filename);
+}
+
+void poEditFrame::OnSaveAs(wxCommandEvent&)
+{
+    DoSaveAs(GetSaveAsFilename(m_catalog, m_fileName));
 }
 
 
@@ -991,15 +1023,21 @@ void poEditFrame::OnNew(wxCommandEvent& event)
     dlg.TransferTo(catalog);
     if (dlg.ShowModal() == wxID_OK)
     {
+        wxString file = GetSaveAsFilename(catalog, wxEmptyString);
+        if (file.empty())
+        {
+            delete catalog;
+            return;
+        }
+
         CancelItemsValidation();
 
         dlg.TransferFrom(catalog);
         delete m_catalog;
         m_catalog = catalog;
         m_list->CatalogChanged(m_catalog);
-        m_fileName = wxEmptyString;
         m_modified = true;
-        OnSave(event);
+        DoSaveAs(file);
         if (!isFromPOT)
         {
             OnUpdate(event);
@@ -1155,7 +1193,7 @@ void poEditFrame::OnListActivated(wxListEvent& event)
 {
     if (m_catalog)
     {
-        int ind = m_list->GetItemData(event.GetIndex());
+        int ind = m_list->GetIndexInCatalog(event.GetIndex());
         if (ind >= (int)m_catalog->GetCount()) return;
         CatalogData& entry = (*m_catalog)[ind];
         if (entry.GetValidity() == CatalogData::Val_Invalid)
@@ -1171,7 +1209,7 @@ void poEditFrame::OnListActivated(wxListEvent& event)
 
 void poEditFrame::OnReferencesMenu(wxCommandEvent& event)
 {
-    int selItem = m_list->GetItemData(m_sel);
+    int selItem = m_list->GetIndexInCatalog(m_sel);
     if (selItem < 0 || selItem >= (int)m_catalog->GetCount()) return;
 
     const wxArrayString& refs = (*m_catalog)[selItem].GetReferences();
@@ -1230,12 +1268,12 @@ void poEditFrame::ShowReference(int num)
     if (wxConfig::Get()->Read(_T("open_editor_immediately"), (long)false))
     {
         FileViewer::OpenInEditor(basepath,
-                                 (*m_catalog)[m_list->GetItemData(m_sel)].GetReferences()[num]);
+                                 (*m_catalog)[m_list->GetIndexInCatalog(m_sel)].GetReferences()[num]);
     }
     else
     {
         FileViewer *w = new FileViewer(this, basepath,
-                                       (*m_catalog)[m_list->GetItemData(m_sel)].GetReferences(),
+                                       (*m_catalog)[m_list->GetIndexInCatalog(m_sel)].GetReferences(),
                                        num);
         if (w->FileOk())
             w->Show(true);
@@ -1309,14 +1347,19 @@ void poEditFrame::OnShadedListFlag(wxCommandEvent& event)
 
 void poEditFrame::OnInsertOriginal(wxCommandEvent& event)
 {
-    if (!m_textTransPlural.empty())
+    if (!m_textTrans->IsShown())
     {
+        // plural form entry:
         wxString orig = m_textOrigPlural->GetValue();
         for (size_t i = 0; i < m_textTransPlural.size(); i++)
             m_textTransPlural[i]->SetValue(orig);
+
+        if (m_textTransSingularForm)
+            m_textTransSingularForm->SetValue(m_textOrig->GetValue());
     }
     else
     {
+        // singular form entry:
         m_textTrans->SetValue(m_textOrig->GetValue());
     }
 }
@@ -1417,7 +1460,7 @@ void poEditFrame::UpdateFromTextCtrl(int item)
     if (m_catalog == NULL) return;
     if (item == -1) item = m_sel;
     if (m_sel == -1 || m_sel >= m_list->GetItemCount()) return;
-    int ind = m_list->GetItemData(item);
+    int ind = m_list->GetIndexInCatalog(item);
     if (ind >= (int)m_catalog->GetCount()) return;
 
     CatalogData& entry = (*m_catalog)[ind];
@@ -1520,7 +1563,7 @@ void poEditFrame::UpdateToTextCtrl(int item)
     if (m_catalog == NULL) return;
     if (item == -1) item = m_sel;
     if (item == -1 || item >= m_list->GetItemCount()) return;
-    int ind = m_list->GetItemData(item);
+    int ind = m_list->GetIndexInCatalog(item);
     if (ind >= (int)m_catalog->GetCount()) return;
 
     const CatalogData& entry = (*m_catalog)[ind];
@@ -1868,7 +1911,7 @@ bool poEditFrame::WriteCatalog(const wxString& catalog)
 
 void poEditFrame::OnEditComment(wxCommandEvent& event)
 {
-    int selItem = m_list->GetItemData(m_sel);
+    int selItem = m_list->GetIndexInCatalog(m_sel);
     if (selItem < 0 || selItem >= (int)m_catalog->GetCount()) return;
 
     wxString comment = convertToLocalCharset(
@@ -1907,7 +1950,7 @@ void poEditFrame::OnPurgeDeleted(wxCommandEvent& WXUNUSED(event))
 void poEditFrame::OnAutoTranslate(wxCommandEvent& event)
 {
     int ind = event.GetId() - ED_POPUP_TRANS;
-    (*m_catalog)[m_list->GetItemData(m_sel)].SetTranslation(m_autoTranslations[ind]);
+    (*m_catalog)[m_list->GetIndexInCatalog(m_sel)].SetTranslation(m_autoTranslations[ind]);
     UpdateToTextCtrl();
     // VS: This dirty trick ensures proper refresh of everything:
     m_edittedTextOrig.clear();
@@ -2205,7 +2248,7 @@ void poEditFrame::OnCommentWindowText(wxCommandEvent&)
     wxString comment;
     comment = convertFromLocalCharset(
             CommentDialog::AddStartHash(m_textComment->GetValue()));
-    CatalogData& data((*m_catalog)[m_list->GetItemData(m_sel)]);
+    CatalogData& data((*m_catalog)[m_list->GetIndexInCatalog(m_sel)]);
 
     wxLogTrace(_T("poedit"), _T("   comm:'%s'"), comment.c_str());
     wxLogTrace(_T("poedit"), _T("datcomm:'%s'"), data.GetComment().c_str());
@@ -2233,6 +2276,7 @@ void poEditFrame::OnIdle(wxIdleEvent& event)
 
 void poEditFrame::OnEndProcess(wxProcessEvent& event)
 {
+    m_gettextProcess = NULL;
     event.Skip(); // deletes wxProcess object
     EndItemValidation();
     wxWakeUpIdle();
@@ -2256,7 +2300,7 @@ void poEditFrame::RestartItemsValidation()
 void poEditFrame::BeginItemValidation()
 {
     int item = m_itemsToValidate.front();
-    int index = m_list->GetItemData(item);
+    int index = m_list->GetIndexInCatalog(item);
     CatalogData& dt = (*m_catalog)[index];
 
     if (!dt.IsTranslated())
@@ -2286,8 +2330,11 @@ void poEditFrame::BeginItemValidation()
     m_validationProcess.tmp1 = tmp1;
     m_validationProcess.tmp2 = tmp2;
 
-    if (ExecuteGettextNonblocking(cmdline, &m_validationProcess, this))
+    wxProcess *process =
+        ExecuteGettextNonblocking(cmdline, &m_validationProcess, this);
+    if (process)
     {
+        m_gettextProcess = process;
         m_itemBeingValidated = item;
         m_itemsToValidate.pop_front();
     }
@@ -2299,13 +2346,15 @@ void poEditFrame::BeginItemValidation()
 
 void poEditFrame::EndItemValidation()
 {
+    wxASSERT( m_catalog );
+
     wxRemoveFile(m_validationProcess.tmp1);
     wxRemoveFile(m_validationProcess.tmp2);
 
     if (m_itemBeingValidated != -1)
     {
         int item = m_itemBeingValidated;
-        int index = m_list->GetItemData(item);
+        int index = m_list->GetIndexInCatalog(item);
         CatalogData& dt = (*m_catalog)[index];
 
         bool ok = (m_validationProcess.ExitCode == 0);
@@ -2391,6 +2440,7 @@ void poEditFrame::RecreatePluralTextCtrls()
         m_textTransPlural[i]->PopEventHandler(true/*delete*/);
     m_textTransPlural.clear();
     m_pluralNotebook->DeleteAllPages();
+    m_textTransSingularForm = NULL;
 
     if (!m_catalog)
         return;
@@ -2432,6 +2482,9 @@ void poEditFrame::RecreatePluralTextCtrls()
         txt->PushEventHandler(new TextctrlHandler(this));
         m_textTransPlural.push_back(txt);
         m_pluralNotebook->AddPage(txt, desc);
+
+        if (example == 1)
+            m_textTransSingularForm = txt;
     }
 
     delete calc;
@@ -2452,7 +2505,7 @@ void poEditFrame::OnListRightClick(wxMouseEvent& event)
         list->SetItemState(item, wxLIST_STATE_SELECTED,
                                  wxLIST_STATE_SELECTED);
 
-    wxMenu *menu = GetPopupMenu(m_list->GetItemData(m_sel));
+    wxMenu *menu = GetPopupMenu(m_list->GetIndexInCatalog(m_sel));
     if (menu)
     {
         list->PopupMenu(menu, event.GetPosition());
@@ -2516,7 +2569,7 @@ void poEditFrame::OnSetBookmark(wxCommandEvent& event)
     // Set bookmark if different from the current value for the item,
     // else unset it
     int bkIndex = -1;
-    int selItemIndex = m_list->GetItemData(m_sel);
+    int selItemIndex = m_list->GetIndexInCatalog(m_sel);
 
     Bookmark bk = static_cast<Bookmark>(event.GetId() - ED_BOOKMARK_SET);
     if (m_catalog->GetBookmarkIndex(bk) == selItemIndex)
