@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: edframe.h,v 1.49 2005/06/19 16:43:20 vaclavslavik Exp $
+ *  $Id: edframe.h,v 1.52 2005/09/30 22:19:04 vaclavslavik Exp $
  *
  *  Editor frame
  *
@@ -151,6 +151,8 @@ class poEditFrame : public wxFrame
         void OnQuit(wxCommandEvent& event);
         void OnSave(wxCommandEvent& event);
         void OnSaveAs(wxCommandEvent& event);
+        wxString GetSaveAsFilename(Catalog *cat, const wxString& current);
+        void DoSaveAs(const wxString& filename);
         void OnOpen(wxCommandEvent& event);
         void OnOpenHist(wxCommandEvent& event);
 #ifdef __WXMSW__
@@ -222,6 +224,7 @@ class poEditFrame : public wxFrame
             wxString tmp1, tmp2;
         };
 
+        wxProcess *m_gettextProcess;
         int m_itemBeingValidated;
         std::list<int> m_itemsToValidate;
         ValidationProcessData m_validationProcess;
@@ -249,6 +252,7 @@ class poEditFrame : public wxFrame
         poEditListCtrl *m_list;
         wxTextCtrl *m_textOrig, *m_textOrigPlural, *m_textTrans, *m_textComment, *m_textAutoComments;
         std::vector<wxTextCtrl*> m_textTransPlural;
+        wxTextCtrl *m_textTransSingularForm;
         wxNotebook *m_pluralNotebook;
         wxGauge *m_statusGauge;
         wxStaticText *m_labelSingular, *m_labelPlural;
