@@ -22,7 +22,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: edlistctrl.cpp,v 1.11 2005/06/21 18:28:28 vaclavslavik Exp $
+ *  $Id: edlistctrl.cpp,v 1.12 2005/07/05 22:04:05 vaclavslavik Exp $
  *
  *  List view control
  *
@@ -379,7 +379,7 @@ void poEditListCtrl::OnSize(wxSizeEvent& event)
     event.Skip();
 }
 
-long poEditListCtrl::GetItemData(long item) const
+long poEditListCtrl::GetIndexInCatalog(long item) const
 {
     if (item < m_itemIndexToCatalogIndexArray.size())
         return m_itemIndexToCatalogIndexArray[item];
