@@ -22,7 +22,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: edlistctrl.h,v 1.9 2005/06/21 18:28:29 vaclavslavik Exp $
+ *  $Id: edlistctrl.h,v 1.10 2005/07/05 22:04:05 vaclavslavik Exp $
  *
  *  List view control
  *
@@ -76,9 +76,8 @@ class poEditListCtrl : public wxListView
         virtual wxListItemAttr * OnGetItemAttr(long item) const;
         virtual int OnGetItemImage(long item) const;
 
-        /// Overriden GetItemData that returns the catalog index
-        /// for the given item.
-        long GetItemData(long item) const;
+        /// Returns item's index in the catalog
+        long GetIndexInCatalog(long item) const;
 
         /// Returns the list item index for the given catalog index
         int GetItemIndex(int catalogIndex) const;
