@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: gexecute.h,v 1.8 2005/06/19 16:43:21 vaclavslavik Exp $
+ *  $Id: gexecute.h,v 1.9 2005/08/07 21:30:13 vaclavslavik Exp $
  *
  *  Gettext execution code
  *
@@ -51,8 +51,8 @@ extern bool ExecuteGettext(const wxString& cmdline,
 
 /** Nonblocking version of the above -- upon termination, EVT_END_PROCESS
     event is delivered to \a parent and \a data are filled. */
-extern bool ExecuteGettextNonblocking(const wxString& cmdline,
-                                      GettextProcessData *data,
-                                      wxEvtHandler *parent);
+extern wxProcess *ExecuteGettextNonblocking(const wxString& cmdline,
+                                            GettextProcessData *data,
+                                            wxEvtHandler *parent);
 
 #endif // _GEXECUTE_H_
