@@ -1,3 +1,32 @@
+/*
+ *  This file is part of poEdit (http://www.poedit.org)
+ *
+ *  Copyright (C) 1999-2005 Vaclav Slavik
+ *
+ *  Permission is hereby granted, free of charge, to any person obtaining a
+ *  copy of this software and associated documentation files (the "Software"),
+ *  to deal in the Software without restriction, including without limitation
+ *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
+ *  and/or sell copies of the Software, and to permit persons to whom the
+ *  Software is furnished to do so, subject to the following conditions:
+ *
+ *  The above copyright notice and this permission notice shall be included in
+ *  all copies or substantial portions of the Software.
+ *
+ *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+ *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+ *  DEALINGS IN THE SOFTWARE.
+ *
+ *  $Id: isocodes.cpp,v 1.14 2005/06/19 16:43:21 vaclavslavik Exp $
+ *
+ *  This file contains languages & countries names and 2-letter codes as
+ *  defined by ISO 639 and ISO 3166 standards.
+ *
+ */
 
 #include <wx/wxprec.h>
 
@@ -50,11 +79,12 @@ LanguageStruct isoLanguages[] =
     {_T("fj"), _T("Fijian")},
     {_T("fo"), _T("Faroese")},
     {_T("fr"), _T("French")},
+    {_T("fur"), _T("Friulian")},
     {_T("fy"), _T("Frisian")},
 
     {_T("ga"), _T("Irish")},
     {_T("gd"), _T("Gaelic")},
-    {_T("gl"), _T("Gallegan")},
+    {_T("gl"), _T("Galician")},
     {_T("gn"), _T("Guarani")},
     {_T("gu"), _T("Gujarati")},
 
@@ -90,7 +120,7 @@ LanguageStruct isoLanguages[] =
     {_T("ku"), _T("Kurdish")},
     {_T("kv"), _T("Komi")},
     {_T("kw"), _T("Cornish")},
-    {_T("ky"), _T("Kirghiz")},
+    {_T("ky"), _T("Kyrgyz")},
 
     {_T("la"), _T("Latin")},
     {_T("lb"), _T("Letzeburgesch")},
@@ -194,7 +224,7 @@ LanguageStruct isoLanguages[] =
     {_T("za"), _T("Zhuang")},
     {_T("zh"), _T("Chinese")},
     {_T("zu"), _T("Zulu")},
-    
+
     {NULL, NULL}
 };
 
@@ -443,7 +473,7 @@ LanguageStruct isoCountries[] =
     {_T("YU"), _T("YUGOSLAVIA")},
     {_T("ZM"), _T("ZAMBIA")},
     {_T("ZW"), _T("ZIMBABWE")},
-    
+
     {NULL, NULL}
 };
 
