@@ -1,16 +1,31 @@
-
 /*
-
-    poedit, a wxWindows i18n catalogs editor
-
-    ---------------
-      parser.cpp
-    
-      Database of available parsers
-    
-      (c) Vaclav Slavik, 1999,2004
-
-*/
+ *  This file is part of poEdit (http://www.poedit.org)
+ *
+ *  Copyright (C) 1999-2005 Vaclav Slavik
+ *
+ *  Permission is hereby granted, free of charge, to any person obtaining a
+ *  copy of this software and associated documentation files (the "Software"),
+ *  to deal in the Software without restriction, including without limitation
+ *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
+ *  and/or sell copies of the Software, and to permit persons to whom the
+ *  Software is furnished to do so, subject to the following conditions:
+ *
+ *  The above copyright notice and this permission notice shall be included in
+ *  all copies or substantial portions of the Software.
+ *
+ *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+ *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+ *  DEALINGS IN THE SOFTWARE.
+ *
+ *  $Id: parser.cpp,v 1.10 2005/06/19 16:43:21 vaclavslavik Exp $
+ *
+ *  Database of available parsers
+ *
+ */
 
 
 #include <wx/wxprec.h>
@@ -84,7 +99,16 @@ void ParsersDB::Write(wxConfigBase *cfg)
         cfg->SetPath(oldpath);
     }
 }
-
+    
+int ParsersDB::FindParser(const wxString& name)
+{
+    for (size_t i = 0; i < GetCount(); i++)
+    {
+        if ((*this)[i].Name == name)
+            return int(i);
+    }
+    return -1;
+}
 
 
 wxArrayString Parser::SelectParsable(const wxArrayString& files)
@@ -156,4 +180,3 @@ wxString Parser::GetCommand(const wxArrayString& files,
     
     return cmdline;
 }
-
