@@ -1,16 +1,31 @@
-
 /*
-
-    poedit, a wxWindows i18n catalogs editor
-
-    ---------------
-      parser.h
-    
-      Database of available parsers
-    
-      (c) Vaclav Slavik, 1999,2004
-
-*/
+ *  This file is part of poEdit (http://www.poedit.org)
+ *
+ *  Copyright (C) 1999-2005 Vaclav Slavik
+ *
+ *  Permission is hereby granted, free of charge, to any person obtaining a
+ *  copy of this software and associated documentation files (the "Software"),
+ *  to deal in the Software without restriction, including without limitation
+ *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
+ *  and/or sell copies of the Software, and to permit persons to whom the
+ *  Software is furnished to do so, subject to the following conditions:
+ *
+ *  The above copyright notice and this permission notice shall be included in
+ *  all copies or substantial portions of the Software.
+ *
+ *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+ *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+ *  DEALINGS IN THE SOFTWARE.
+ *
+ *  $Id: parser.h,v 1.8 2005/06/19 16:43:21 vaclavslavik Exp $
+ *
+ *  Database of available parsers
+ *
+ */
 
 #ifndef _PARSER_H_
 #define _PARSER_H_
@@ -78,12 +93,15 @@ class WXDLLEXPORT wxConfigBase;
  */
 class ParsersDB : public ParserArray
 {
-    public:
-        /// Reads DB from registry/dotfile.
-        void Read(wxConfigBase *cfg);
-        
-        /// Write DB to registry/dotfile.
-        void Write(wxConfigBase *cfg);
+public:
+    /// Reads DB from registry/dotfile.
+    void Read(wxConfigBase *cfg);
+    
+    /// Write DB to registry/dotfile.
+    void Write(wxConfigBase *cfg);
+
+    /// Returns index of parser with given name or -1 if it can't be found:
+    int FindParser(const wxString& name);
 };
 
 #endif // _PARSER_H_
